// $Id: Viewer.java,v 1.17 2000/11/21 17:15:58 kmbarber Exp $


/**
 * GUI viewer for DAML content found at a specified URI.
 */
class Viewer
{
    public static String version = "2000-11-21"; // + denotes development version

    /**
     * return identification information
     */
    public static String getVersionString()
    {
	return "DAML Viewer " 
	    + (isApplet() ? "Applet " : "")
	    + version
	    + ", created by Mike Dean and Kelly Barber of BBN Technologies";
    }

    String uri = null;
    java.util.Vector objects;
    int nstatements = 0;

    /**
     * all Resource Nodes, indexed by URI
     */
    java.util.Hashtable resources = new java.util.Hashtable();
    Resource getNode(String uri)
    {
	Resource retval;

	if ((retval = (Resource) resources.get(uri)) == null)
	    {
		retval = new Resource(uri);
		resources.put(uri, retval);
	    }
	return retval;
    }

    /**
     * create a Viewer for DAML statements found at the specified URI
     */
    Viewer(String uri)
	throws Exception
    {
	this.uri = uri;
	
	// note progress
	javax.swing.JFrame progressFrame = new javax.swing.JFrame("DAML Viewer");
	javax.swing.DefaultBoundedRangeModel progressModel = new javax.swing.DefaultBoundedRangeModel();
	javax.swing.JProgressBar progressBar = new javax.swing.JProgressBar(progressModel);
	progressBar.setString("loading " + uri);
	progressBar.setStringPainted(true);
	progressFrame.getContentPane().add(progressBar);
	int height = 100;
	int width = 300;
	java.awt.Dimension screen = java.awt.Toolkit.getDefaultToolkit().getScreenSize();
	int y = (screen.height - height) / 2;
	int x = (screen.width - width) / 2;
	progressFrame.setBounds(x, y, width, height);
	progressFrame.setVisible(true);
		
	// get model
	org.w3c.rdf.util.RDFFactory f = new org.w3c.rdf.util.RDFFactoryImpl();
	org.w3c.rdf.model.Model m = f.createModel();
	try {
	    org.w3c.rdf.util.RDFUtil.parse(uri, f.createParser(), m);
	} catch (Exception e) {
	    javax.swing.JOptionPane.showMessageDialog(progressBar, 
						      e);
	    progressFrame.dispose();
	    return;
	}
	progressModel.setMaximum(m.size());

	// make Nodes and Statements
	java.util.Enumeration en;
	for(en = m.elements(); en.hasMoreElements();)
	    {
		org.w3c.rdf.model.Statement s = (org.w3c.rdf.model.Statement) en.nextElement();
		new Statement(this,
			      s);

		nstatements++;
		progressModel.setValue(nstatements);
	    }
	progressFrame.dispose();
	
	// display NodesView
	new NodesView(this);
    }

    static java.applet.Applet applet = null;
    /**
     * are we running as an applet?
     */
    public static boolean isApplet()
    {
	return (applet != null);
    }

    /**
     * indicate that this process is running as an applet rather than an
     * application/command
     */
    public static void setApplet(java.applet.Applet newApplet)
    {
	applet = newApplet;
    }

    /**
     * stop running.
     */
    public static void exit(int code)
    {
	if (isApplet())
	    {
		// XXX - implement
		// don't do anything!
	    }
	else
	    System.exit(code);
    }

    /**
     * run Viewer as a command
     */
    public static void main(String args[])
	throws Exception
    {
	// allow for new input
	new URIInput();

	for (int i = 0; i < args.length; i++)
	    {
		new Viewer(args[i]);
	    }
    }
}





